Summary:	SParse Object Oriented Linear Equations Solver
Name:		spooles
Version:	2.2
Release:	3
License:	Public domain
Group:		Applications/Library
Source:		%{name}-%{version}.tar.bz2
Source1:	Make.inc
Patch:		spooles-memcpy.patch
URL:		http://netlib.bell-labs.com/netlib/linalg/spooles/spooles.2.2.html
BuildRoot:	/var/tmp/%{name}-%{version}-root-%(id -u -n)
BuildArch:	i386 i686 x86_64
Prefix:		/usr

%description
SPOOLES is a library for solving sparse real and complex linear systems of
equations, written in the C language using object oriented design.
At present, there is the following functionality:

   1. Compute multiple minimum degree, generalized nested dissection and
      multisection orderings of matrices with symmetric structure.

   2. Factor and solve square linear systems of equations with symmetric
      structure, with or without pivoting for stability. The factorization can
      be symmetric LDLT, Hermitian LDLH, or nonsymmetric LDU. A direct
      factorization or a drop tolerance factorization can be computed.
      The factors and solve can be done in serial mode, multithreaded with
      Solaris or POSIX threads, or with MPI.

   3. Factor and solve overdetermined full rank systems of equations using
      a multifrontal QR factorization, in serial or using POSIX threads.

   4. Solve square linear systems using a variety of Krylov iterative methods.
      The preconditioner is a drop tolerance factorization, constructed with
      or without pivoting for stability. 

%prep
%setup -q -n %{name}-%version
%patch -p1
/bin/cp -f %{SOURCE1} .

%build
make lib
cd MPI ; make lib; cd ..
cd MT  ; make lib; cd ..
cd LinSol/srcST; make Bridge.a; cd ../..
cd LinSol/srcMT; make BridgeMT.a; cd ../..
cd LinSol/srcMPI; make BridgeMPI.a; cd ../..

echo 1>&2 "Building shared libraries:"
/bin/rm -rf tmp
mkdir tmp
cd tmp
for lib in spooles MPI/src/spoolesMPI MT/src/spoolesMT \
	   LinSol/srcST/Bridge LinSol/srcMT/BridgeMT LinSol/srcMPI/BridgeMPI
do
    echo 1>&2 "${lib}.so ..."
    ar x ../${lib}.a
    gcc -shared -o ../${lib}.so *.o
    rm -f *.o
done
cd ..
rmdir tmp

%install
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT{%{_libdir},%{_includedir},%{_datadir},%{_docdir}}

/bin/cp -pf spooles.so $RPM_BUILD_ROOT%{_libdir}/libspooles.so
/bin/cp -pf MPI/src/spoolesMPI.so $RPM_BUILD_ROOT%{_libdir}/libspoolesMPI.so
/bin/cp -pf MT/src/spoolesMT.so $RPM_BUILD_ROOT%{_libdir}/libspoolesMT.so
/bin/cp -pf LinSol/srcST/Bridge.so $RPM_BUILD_ROOT%{_libdir}/libBridge.so
/bin/cp -pf LinSol/srcMT/BridgeMT.so $RPM_BUILD_ROOT%{_libdir}/libBridgeMT.so
/bin/cp -pf LinSol/srcMPI/BridgeMPI.so $RPM_BUILD_ROOT%{_libdir}/libBridgeMPI.so

#/bin/cp -pf ./LinSol/srcST/Bridge.a $RPM_BUILD_ROOT%{_libdir}/libBridge.so
#/bin/cp -pf ./LinSol/srcMPI/BridgeMPI.a $RPM_BUILD_ROOT%{_libdir}/libBridgeMPI.so

# install header files into %{_includedir}/spooles
INCDIR=$RPM_BUILD_ROOT%{_includedir}

for d in `ls -C1 */*.h | awk -F/ '{print $1}' | sort -u`
do
    mkdir -p ${INCDIR}/spooles/$d
    cd $d
    for h in `ls *.h`
    do
	sed -e 's/#include "\.\.\(.*\.h\)"/#include <spooles\1>/' \
	    -e 's/#include "\([a-zA-Z0-9]*\.h\)"/#include <spooles\/'$d'\/\1>/'\
	    $h >${INCDIR}/spooles/${d}/$h
    done
    cd ..
done

for h in `ls *.h`
do
    sed -e 's/#include "\(.*\)"/#include <spooles\/\1>/' $h \
	> ${INCDIR}/spooles/$h
done

echo "#include <spooles/MPI/spoolesMPI.h>" > ${INCDIR}/spoolesMPI.h

/bin/chmod -R a+rX $RPM_BUILD_ROOT/.

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%post
/sbin/ldconfig

%postun
/sbin/ldconfig

%files
%{_includedir}/*
%{_libdir}/lib*

%changelog
